| Title: | A User-Friendly 'shiny' Application for Exploring Associations and Visual Patterns |
|---|---|
| Description: | A user-friendly 'shiny' application to explore statistical associations and visual patterns in multivariate datasets. The app provides interactive correlation networks, bivariate plots, and summary tables for different types of variables (numeric and categorical). It also supports optional survey weights and range-based filters on association strengths, making it suitable for the exploration of survey and public data by non-technical users, journalists, educators, and researchers. For background and methodological details, see Soetewey et al. (2025) <doi:10.1016/j.softx.2025.102483>. |
| Authors: | Antoine Soetewey [aut, cre] (ORCID: <https://orcid.org/0000-0001-8159-0804>), Cédric Heuchenne [aut] (0000-0002-3150-3044), Arnaud Claes [aut] (0000-0003-0716-0798), Antonin Descampe [aut] (0000-0002-0943-4126) |
| Maintainer: | Antoine Soetewey <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.6 |
| Built: | 2026-05-26 06:41:21 UTC |
| Source: | https://github.com/antoinesoetewey/associationexplorer2 |
This function launches the AssociationExplorer2 Shiny application in your default web browser. The app provides interactive tools for exploring statistical associations, correlation networks, bivariate visualizations, and summary tables, with optional support for survey weights and range-based filtering of association strengths.
run_associationexplorer(...)run_associationexplorer(...)
... |
Additional arguments passed to |
The function is called for its side effect of launching the app.
if (interactive()) { run_associationexplorer() }if (interactive()) { run_associationexplorer() }